==> pupa-0.7.0-py2.py3-none-any.whl: pupa/scrape/schemas/vote_event.py <==
from .common import sources, extras, fuzzy_datetime_blank
from opencivicdata import common


schema = {
    "type": "object",
    "properties": {
        'identifier': {"type": "string", "blank": True,},
        'motion_text': {"type": "string" },
        'motion_classification': {"items": {"type": "string"},
                                  "type": "array"},
        'start_date': fuzzy_datetime_blank,
        'end_date': fuzzy_datetime_blank,
        'result': {"type": "string", "enum": common.VOTE_RESULTS},
        'organization': {"type": ["string", "null"]},
        'legislative_session': {"type": "string"},
        'bill': {"type": ["string", "null"]},
        'bill_action': {"type": ["string", "null"]},
        'votes': {
            "items": {
                "type": "object",
                "properties": {
                    "option": {"type": "string", "enum": common.VOTE_OPTIONS },
                    "voter_name": {"type": "string"},
                    "voter_id": {"type": "string"},
                    "note": {"type": "string", "blank": True},
                },
            },
        },
        'counts': {
            "items": {
                "properties": {
                    "option": {"type": "string", "enum": common.VOTE_OPTIONS },
                    "value": {"type": "integer", "minimum": 0},
                },
                "type": "object"
            },
        },

        'sources': sources,
        'extras': extras,
        'pupa_id': {"type": ["string", "null"]},
    }
}

==> pupa-0.8.0-py2.py3-none-any.whl: pupa/scrape/schemas/vote_event.py <==
from .common import sources, extras, fuzzy_datetime_blank
from opencivicdata import common


schema = {
    "type": "object",
    "properties": {
        'identifier': {"type": "string", "blank": True},
        'motion_text': {"type": "string"},
        'motion_classification': {"items": {"type": "string"},
                                  "type": "array"},
        'start_date': fuzzy_datetime_blank,
        'end_date': fuzzy_datetime_blank,
        'result': {"type": "string", "enum": common.VOTE_RESULTS},
        'organization': {"type": ["string", "null"]},
        'legislative_session': {"type": "string"},
        'bill': {"type": ["string", "null"]},
        'bill_action': {"type": ["string", "null"]},
        'votes': {
            "items": {
                "type": "object",
                "properties": {
                    "option": {"type": "string", "enum": common.VOTE_OPTIONS},
                    "voter_name": {"type": "string"},
                    "voter_id": {"type": "string"},
                    "note": {"type": "string", "blank": True},
                },
            },
        },
        'counts': {
            "items": {
                "properties": {
                    "option": {"type": "string", "enum": common.VOTE_OPTIONS},
                    "value": {"type": "integer", "minimum": 0},
                },
                "type": "object"
            },
        },

        'sources': sources,
        'extras': extras,
        'pupa_id': {"type": ["string", "null"]},
    }
}
